@@ -17,7 +17,7 @@ use Data::Identifier;
 
 use parent qw(Data::Identifier::Interface::Userdata Data::Identifier::Interface::Simple);
 
-our $VERSION = v0.04;
+our $VERSION = v0.05;
 
 
 sub new {
@@ -195,6 +195,40 @@ sub as {
 }
 
 
+sub eq {
+    my ($self, $other, @opts) = @_;
+
+    croak 'Stray options passed' if scalar @opts;
+
+    foreach my $dc ($self, $other) {
+        if (!defined($dc)) {
+            $dc = __PACKAGE__->null;
+        } elsif (!eval {$dc->isa(__PACKAGE__)}) {
+            $dc = __PACKAGE__->new(from => $dc);
+        }
+    }
+
+    return $self->datecode == $other->datecode;
+}
+
+
+sub cmp {
+    my ($self, $other, @opts) = @_;
+
+    croak 'Stray options passed' if scalar @opts;
+
+    foreach my $dc ($self, $other) {
+        if (!defined($dc)) {
+            $dc = __PACKAGE__->null;
+        } elsif (!eval {$dc->isa(__PACKAGE__)}) {
+            $dc = __PACKAGE__->new(from => $dc);
+        }
+    }
+
+    return $self->datecode <=> $other->datecode;
+}
+
+
 sub is_utc {
     my ($self, @opts) = @_;
 
@@ -219,6 +253,19 @@ sub is_null {
 }
 
 
+sub assert_16bit {
+    my ($self, @opts) = @_;
+
+    croak 'Stray options passed' if scalar @opts;
+
+    unless ($self->{datecode} >= 0 && $self->{datecode} <= 0xFFFF) {
+        croak 'Datecode is outside of 16 bit range';
+    }
+
+    return $self;
+}
+
+
 sub precision {
     my ($self, @opts) = @_;
     my $iso_len = length($self->iso8601 // '');
@@ -335,12 +382,21 @@ SIRTX::Datecode - module for interacting with SIRTX Datecodes
 
 =head1 VERSION
 
-version v0.04
+version v0.05
 
 =head1 SYNOPSIS
 
     use SIRTX::Datecode;
 
+    my SIRTX::Datecode $dc = SIRTX::Datecode->new($type => $value [, %opts ]);
+
+    my $iso8601 = $dc->iso8601;
+    my $year    = $dc->year;
+
+    if ($dc->eq($other)) {
+        # ...
+    }
+
 This module provides support to convert between different date formats and SIRTX datecodes.
 SIRTX datecodes allow to encode dates in the range of years 1582 to 2440 into just 16 bits
 by using a variable precision. They also allow for numeric ordering over their full range.
@@ -430,6 +486,56 @@ Returns the datecode as an ISO-8601 date string.
 
 This is a proxy for L<Data::Identifier/as>.
 
+=head2 eq
+
+    my $bool = $dc->eq($other); # $identifier must be non-undef
+    # or:
+    my $bool = SIRTX::Datecode::eq($dc, $other); # $dc can be undef
+
+(since v0.05)
+
+Compares two datecodes to be equal.
+
+If both datecodes are C<undef> they are considered equal.
+
+If C<$dc> or C<$other> is not an instance of L<SIRTX::Datecode> or C<undef>
+it is converted using L</new> with C<from>.
+
+=head2 cmp
+
+    my $val = $dc->cmp($other); # $dc must be non-undef
+    # or:
+    my $val = SIRTX::Datecode::cmp($dc, $other); # $dc can be undef
+
+(since v0.05)
+
+Compares two datecodes similar to C<E<lt>=E<gt>>. THis method can be used to order datecodes.
+To check for them to be equal see L</eq>.
+
+The parameters are parsed the same way as L</eq>.
+
+If this method is used for sorting the exact resulting order is not defined. However:
+
+=over
+
+=item *
+
+The order is stable (for any given version of this module)
+
+=item *
+
+For any two datecodes with the same precision the order is chronological
+
+=item *
+
+For any two non-overlapping datecodes the order is chronological
+
+=item *
+
+The order is the same for C<$a-E<gt>cmp($b)> as for C<- $b-E<gt>cmp($a)>.
+
+=back
+
 =head2 is_utc
 
     my $bool = $dc->is_utc;
@@ -458,6 +564,15 @@ See also: L</is_utc>.
 
 Returns a true-ish value if the datecode is the null value and false-ish otherwise.
 
+=head2 assert_16bit
+
+    $dc->assert_16bit;
+
+(since v0.05)
+
+Asserts that the datecode fits into 16 bit.
+If it doesn't this method will C<die>.
+
 =head2 precision
 
     my $precision = $dc->precision;
